-- **************************************************
-- Provide Moho with the name of this script object
-- **************************************************

ScriptName = "Syn_ScrubWorkspace"

-- **************************************************
-- General information about this script
-- **************************************************

Syn_ScrubWorkspace = {}

function Syn_ScrubWorkspace:Name()
	return "Scrub Workspace"
end

function Syn_ScrubWorkspace:Version()
	return "1.2"
end

function Syn_ScrubWorkspace:Description()
	return "Click & drag in workspace to scrub timeline"
end

function Syn_ScrubWorkspace:Creator()
	return "(c)2021 J.Wesley Fowler (SynthSin75)"
end

function Syn_ScrubWorkspace:UILabel()
	return "SYN: Scrub Workspace"
end

function Syn_ScrubWorkspace:NonDragMouseMove()
	return false--true -- Call MouseMoved() even if the mouse button is not down
end

function Syn_ScrubWorkspace:LoadPrefs(prefs)
	self.speed = prefs:GetFloat("Syn_ScrubWorkspace.speed", 2)
	self.int = prefs:GetInt("Syn_ScrubWorkspace.int", 1)
end

function Syn_ScrubWorkspace:SavePrefs(prefs)
	prefs:SetFloat("Syn_ScrubWorkspace.speed", self.speed)
	prefs:SetInt("Syn_ScrubWorkspace.int", self.int)
end

-- **************************************************
-- Recurring values
-- **************************************************

Syn_ScrubWorkspace.speed = 2
Syn_ScrubWorkspace.min = .1
Syn_ScrubWorkspace.max = 40
Syn_ScrubWorkspace.int = 1

-- **************************************************
-- The guts of this script
-- **************************************************

function Syn_ScrubWorkspace:NonDragMouseMove()
	return true
end

function Syn_ScrubWorkspace:IsRelevant(moho)
	self.ver = tonumber(string.match(moho:AppVersion(), "(%d+)%p.+"))
	self.app = string.match(moho:AppDir(), "(.+)Support")
	return true
end

function Syn_ScrubWorkspace:OnMouseDown(moho, mouseEvent)
	self.startFrm = moho.frame
	if (self.ver >= 13) then
		local cursor = LM.GUI.Cursor(self.app.."Images/curs_hresize")
		mouseEvent.view:SetCursor(cursor)
	end
end

function Syn_ScrubWorkspace:OnMouseMoved(moho, mouseEvent)
	if (not mouseEvent.view:IsMouseDragging(0)) then
		if (self.ver >= 13) then
			local cursor = LM.GUI.Cursor(self.app.."Images/dragCursor")
			mouseEvent.view:SetCursor(cursor)
		end
		return
	else
		local range = math.ceil(((mouseEvent.pt.x - mouseEvent.startPt.x)/8)*self.speed)
		if (self.startFrm+range*self.int < 0) then
			moho:SetCurFrame(0)
			self.startFrm = 0
			mouseEvent.startPt.x = mouseEvent.pt.x
		else
			moho:SetCurFrame(self.startFrm+range*self.int)
		end
	end
end

function Syn_ScrubWorkspace:OnMouseUp(moho, mouseEvent)
	mouseEvent.view:SetCursor()
end

-- **************************************************
-- Tool options - create and respond to tool's UI
-- **************************************************

Syn_ScrubWorkspace.CHANGE = MOHO.MSG_BASE

function Syn_ScrubWorkspace:DoLayout(moho, layout)
	self.speedText = LM.GUI.TextControl(0, "00.00", self.CHANGE, LM.GUI.FIELD_UFLOAT, "Speed:")
	self.speedText:SetWheelInc(self.min)
	layout:AddChild(self.speedText)
	self.intText = LM.GUI.TextControl(0, "00.00", self.CHANGE, LM.GUI.FIELD_UINT, "Interval:")
	self.intText:SetWheelInc(1)
	layout:AddChild(self.intText)
end

function Syn_ScrubWorkspace:UpdateWidgets(moho)
	self.speedText:SetValue(self.speed)
	self.intText:SetValue(self.int)
end 

function Syn_ScrubWorkspace:HandleMessage(moho, view, msg)
	self.speed = LM.Clamp(self.speedText:FloatValue(), self.min, self.max)
	self.int = LM.Clamp(self.intText:IntValue(), 1, 50)
end